VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
  Persistable = 0  'NotPersistable
  DataBindingBehavior = 0  'vbNone
  DataSourceBehavior  = 0  'vbNone
  MTSTransactionMode  = 0  'NotAnMTSObject
END
Attribute VB_Name = "UserProfile"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = True
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = True
' --- GPL ---
'
' Copyright (C) 2000-2001 SAP AG
'
' This program is free software; you can redistribute it and/or
' modify it under the terms of the GNU General Public License
' as published by the Free Software Foundation; either version 2
' of the License, or (at your option) any later version.
'
' This program is distributed in the hope that it will be useful,
' but WITHOUT ANY WARRANTY; without even the implied warranty of
' MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
' GNU General Public License for more details.
'
' You should have received a copy of the GNU General Public License
' along with this program; if not, write to the Free Software
' Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
'
' --- GPL ---
'////////////////////////////////////////////////////////////////////
'//
'// class:      SAPDBUPUserProfile
'//
'//
'//-----------------------------------------------------------------------
'//
'// responsible:  ( @SAP.com)
'//
'// special area: SAPDBUPO
'//
'// description:  class for loading,saving, ... userprofile of sql studio
'//
'// see also:
'//
'//-----------------------------------------------------------------------
'//
'//  copyright:                Copyright by SAP AG, 2000
'//
'//
'////////////////////////////////////////////////////////////////////
Option Explicit

'module name
Const MODULE_NAME = "UserProfile"

Const LOCAL_ROOT = "LocalRoot"
Const NOVERSIONDEP = "NoVersionDep"
Const PROFILE = "Profile"

Const TABLETYPES = "TABLE_TYPES"
Const STORE_PASSWORDS = "STORE_PASSWORDS"
Const STD_FONT = "STD_FONT"
Const REPLACE_NON_CHARS = "REPLACE_NON_CHARS"
Const STDOBJ_CONFIRMATION = "STDOBJ_CONFIRMATION"
Const STD_TABLEFILTER = "STD_TABLEFILTER"
Const LIMIT_FORLONG = "LIMIT_FORLONG"
Const FONT_REPORT = "FONT_REPORT"
Const STD_EXPANDED_NODES = "STD_EXPANDED_NODES"
Const RESTORE_CATALOG = "RESTORE_CATALOG"
Const OBJECT_SETTINGS = "OBJECT_SETTINGS"
Const CLIPPED_RESULTVIEW = "CLIPPED_RESULTVIEW"
Const ESCAPE_CHAR = "ESCAPE_CHAR"
Const REP_NULLVALUE = "REP_NULLVALUE"
Const QBE_READONLY = "QBE_READONLY"
Const DSQL_FORTEXTCOLOR = "DSQL_FORTEXTCOLOR"
Const DSQL_HIGHLIGHTCOLOR = "DSQL_HIGHLIGHTCOLOR"
Const STD_LOCALROOT = "STD_LOCALROOT"
Const FILTERINPUT_UPPER = "FILTERINPUT_UPPER"
Const COPY_TABSEP = "COPY_TABSEP"
Const ID_CASE_SENSITIV = "ID_CASE_SENSITIV"
Const COPY_RESULT_HEADER = "COPY_RESULT_HEADER"

Private Type Font

    name As String
    FontBold As Boolean
    FontItalic As Boolean
    FontSize As Long
    FontStrikethrough As Boolean
    FontUnderline As Boolean
End Type

Private Const SQL_DATA_AT_EXEC = -2
Private Const SQL_NEED_DATA = 99
Private Const SQL_NO_DATA_FOUND = 100
Private Const SQL_SUCCESS = 0
Private Const SQL_SUCCESS_WITH_INFO = 1
Private Const SQLSTATE_SUCCESS = "00000"
Private Const SQLSTATE_DATA_TRUNCATED = "01004"


'Copy of properties
Private m_oSelectTableTypes             As New TABLETYPES
Private m_oPasswordOptions              As New PasswordOptions
Private m_oAppManagment                 As New AppManagement
Private m_typeUserFont                  As Font
Private m_typeReportFont                As Font
Private m_bReplaceNonCharsInLongColumn  As Boolean
Private m_bConfirmation                 As Boolean
Private m_bRestoreCatalogState          As Boolean
Private m_bClippedResultView            As Boolean
Private m_lLimitForLongColumn           As Long
Private m_lFetchBlockSize               As Long
Private m_lFetchBufferSize              As Long
Private m_sTableFilter                  As String
Private m_sExpandedNodes                As String
Private m_colTableFilter                As New Collection

Private m_sEscapeCharacter              As String
Private m_sRepOfNullValue               As String

Private m_bQBEReadOnly                  As Boolean

Private m_lVersion                      As Long
Private m_lAppVersion                   As Long

Private m_lForTextColor                 As Long

'this value is kept to be compatible to userprofiles from previous versions which used
'color for protected text
Private m_lProtTextColor                As Long
Private m_lHighlightColor               As Long

Private m_sLocalRoot                    As String

'flag, if input of filter box for the catalog table folder is converted to uppercase
Private m_bCMFilterInputUpper           As Boolean

'if rows are copied in the result dailog, they are seperated with tabs
Private m_bCopyColumsTabSep             As Boolean

'create table dialog, column names are case sensitiv
Private m_bIdentifiersCaseSensitiv As Boolean

'copy a query result with columnheader
Private m_bCopyResultWithHeader As Boolean

'global object for registry functions
Private m_oRegFunc                  As New SQLStudioUtil.Registry

Public Function getUserFont(name As String, _
                            FontBold As Boolean, _
                            FontItalic As Boolean, _
                            FontSize As Long, _
                            FontStrikethrough As Boolean, _
                            FontUnderline As Boolean) As Boolean
    
    On Error GoTo errGetUserFont
    
    Const FUNCTION_NAME = "GetUserFont"
        
    name = m_typeUserFont.name
    FontBold = m_typeUserFont.FontBold
    FontItalic = m_typeUserFont.FontItalic
    FontSize = m_typeUserFont.FontSize
    FontStrikethrough = m_typeUserFont.FontStrikethrough
    FontUnderline = m_typeUserFont.FontUnderline
    
    Exit Function
    
errGetUserFont:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Function
Public Function setUserFont(name As String, _
                            FontBold As Boolean, _
                            FontItalic As Boolean, _
                            FontSize As Long, _
                            FontStrikethrough As Boolean, _
                            FontUnderline As Boolean) As Boolean
    On Error GoTo errSetUserFont
    
    Const FUNCTION_NAME = "SetUserFont"
    
    m_typeUserFont.name = name
    m_typeUserFont.FontBold = FontBold
    m_typeUserFont.FontItalic = FontItalic
    m_typeUserFont.FontSize = FontSize
    m_typeUserFont.FontStrikethrough = FontStrikethrough
    m_typeUserFont.FontUnderline = FontUnderline
    
        
    Exit Function
    
errSetUserFont:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Function
Public Function getReportFont(name As String, _
                            FontBold As Boolean, _
                            FontItalic As Boolean, _
                            FontSize As Long, _
                            FontStrikethrough As Boolean, _
                            FontUnderline As Boolean) As Boolean
    
    On Error GoTo errGetReportFont
    
    Const FUNCTION_NAME = "GetReportFont"
    
    getReportFont = False
        
    name = m_typeReportFont.name
    FontBold = m_typeReportFont.FontBold
    FontItalic = m_typeReportFont.FontItalic
    FontSize = m_typeReportFont.FontSize
    FontStrikethrough = m_typeReportFont.FontStrikethrough
    FontUnderline = m_typeReportFont.FontUnderline
    
    
    getReportFont = True
    
    Exit Function
    
errGetReportFont:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Function
Public Function setReportFont(name As String, _
                            FontBold As Boolean, _
                            FontItalic As Boolean, _
                            FontSize As Long, _
                            FontStrikethrough As Boolean, _
                            FontUnderline As Boolean) As Boolean
    On Error GoTo errSetReportFont
    
    Const FUNCTION_NAME = "SetReportFont"
    
    m_typeReportFont.name = name
    m_typeReportFont.FontBold = FontBold
    m_typeReportFont.FontItalic = FontItalic
    m_typeReportFont.FontSize = FontSize
    m_typeReportFont.FontStrikethrough = FontStrikethrough
    m_typeReportFont.FontUnderline = FontUnderline
    
        
    Exit Function
    
errSetReportFont:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Function
Public Property Set selectTableTypes(newSelectTableTypes As TABLETYPES)
    On Error GoTo Err_SET_SelectTableTypes
    
    Const FUNCTION_NAME = "P_SET SelectTableTypes"
    
    'set property
    Set m_oSelectTableTypes = newSelectTableTypes
    
    Exit Property
    
Err_SET_SelectTableTypes:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Property
Public Property Get selectTableTypes() As TABLETYPES
    On Error GoTo err_Get_SelectTableTypes
    
    Const FUNCTION_NAME = "P_Get selectTableTypes"
    
    ' get property
    Set selectTableTypes = m_oSelectTableTypes
    
    Exit Property
    
err_Get_SelectTableTypes:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Property
Public Property Get storePassword() As Boolean
    On Error GoTo err_Get_StorePassword
    
    Const FUNCTION_NAME = "P_Get storePassword"
    
    ' get property
    storePassword = m_oPasswordOptions.storePassword
    
    Exit Property
    
err_Get_StorePassword:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Property
Public Property Let storePassword(bNewUseStoredPw As Boolean)
    On Error GoTo err_Let_StorePassword
    
    Const FUNCTION_NAME = "P_LET StorePassword"
    
    'let property
    m_oPasswordOptions.storePassword = bNewUseStoredPw
    
    Exit Property
    
err_Let_StorePassword:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Property
Public Property Get appManagment() As AppManagement
    On Error GoTo err_Get_AppManagment
    
    Const FUNCTION_NAME = "P_Get appManagment"
    
    ' get property
    Set appManagment = m_oAppManagment
    
    Exit Property
    
err_Get_AppManagment:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Property
Public Property Set appManagment(NewAppManagment As AppManagement)
    On Error GoTo err_Let_AppManagment
    
    Const FUNCTION_NAME = "P_Let appManagment"
    
    'let property
    Set m_oAppManagment = NewAppManagment
    
    Exit Property
    
err_Let_AppManagment:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Property

Public Property Get replaceNonCharsInLongColumns() As Boolean
    On Error GoTo err_Get_ReplaceNonCharsInLongColumns
    
    Const FUNCTION_NAME = "P_Get replaceNonCharsInLongColumns"
    
    ' get property
    replaceNonCharsInLongColumns = m_bReplaceNonCharsInLongColumn
    
    Exit Property
    
err_Get_ReplaceNonCharsInLongColumns:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Property
Public Property Let replaceNonCharsInLongColumns(bNewReplaceNonCharsInLongColumns As Boolean)
    On Error GoTo err_Let_ReplaceNonCharsInLongColumns
    
    Const FUNCTION_NAME = "P_LET ReplaceNonCharsInLongColumns"
    
    'let property
    m_bReplaceNonCharsInLongColumn = bNewReplaceNonCharsInLongColumns
    
    Exit Property
    
err_Let_ReplaceNonCharsInLongColumns:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Property
Public Property Get confirmation() As Boolean
    On Error GoTo err_Get_Confirmation
    
    Const FUNCTION_NAME = "P_Get confirmation"
    
    ' get property
    confirmation = m_bConfirmation
    
    Exit Property
    
err_Get_Confirmation:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Property
Public Property Let confirmation(bNewConfirmation As Boolean)
    On Error GoTo err_Let_Confirmation
    
    Const FUNCTION_NAME = "P_LET Confirmation"
    
    'let property
    m_bConfirmation = bNewConfirmation
    
    Exit Property
    
err_Let_Confirmation:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Property
Public Property Get restoreCatalogState() As Boolean
    On Error GoTo err_Get_RestoreCatalogState
    
    Const FUNCTION_NAME = "P_Get restoreCatalogState"
    
    ' get property
    restoreCatalogState = m_bRestoreCatalogState
    
    Exit Property
    
err_Get_RestoreCatalogState:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Property
Public Property Let restoreCatalogState(bNewRestoreCatalogState As Boolean)
    On Error GoTo err_Let_RestoreCatalogState
    
    Const FUNCTION_NAME = "P_LET RestoreCatalogState"
    
    'let property
    m_bRestoreCatalogState = bNewRestoreCatalogState
    
    Exit Property
    
err_Let_RestoreCatalogState:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Property
Public Property Get limitForLongColumn() As Long
    On Error GoTo err_Get_LimitForLongColumn
    
    Const FUNCTION_NAME = "P_Get limitForLongColumn"
    
    ' get property
    limitForLongColumn = m_lLimitForLongColumn
    
    Exit Property
    
err_Get_LimitForLongColumn:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Property
Public Property Let limitForLongColumn(bNewLimitForLongColumn As Long)
    On Error GoTo err_Let_LimitForLongColumn
    
    Const FUNCTION_NAME = "P_LET LimitForLongColumn"
    
    'let property
    m_lLimitForLongColumn = bNewLimitForLongColumn
    
    Exit Property
    
err_Let_LimitForLongColumn:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Property
Public Property Get clippedResultView() As Boolean
    On Error GoTo err_Get_ClippedResultView
    
    Const FUNCTION_NAME = "P_Get clippedResultView"
    
    ' get property
    clippedResultView = m_bClippedResultView
    
    Exit Property
    
err_Get_ClippedResultView:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Property
Public Property Let clippedResultView(bNewClippedResultView As Boolean)
    On Error GoTo err_Let_ClippedResultView
    
    Const FUNCTION_NAME = "P_LET ClippedResultView"
    
    'let property
    m_bClippedResultView = bNewClippedResultView
    
    Exit Property
    
err_Let_ClippedResultView:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Property
Private Property Get fetchBlockSize() As Long
    On Error GoTo err_Get_FetchBlockSize
    
    Const FUNCTION_NAME = "P_Get fetchBlockSize"
    
    ' get property
    fetchBlockSize = m_lFetchBlockSize
    
    Exit Property
    
err_Get_FetchBlockSize:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Property
Private Property Let fetchBlockSize(lNewFetchBlockSize As Long)
    On Error GoTo err_Let_FetchBlockSize
    
    Const FUNCTION_NAME = "P_LET FetchBlockSize"
    
    'let property
    m_lFetchBlockSize = lNewFetchBlockSize
    
    Exit Property
    
err_Let_FetchBlockSize:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Property
Private Property Get fetchBufferSize() As Long
    On Error GoTo err_Get_FetchBufferSize
    
    Const FUNCTION_NAME = "P_Get fetchBufferSize"
    
    ' get property
    fetchBufferSize = m_lFetchBufferSize
    
    Exit Property
    
err_Get_FetchBufferSize:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Property
Private Property Let fetchBufferSize(lNewFetchBufferSize As Long)
    On Error GoTo err_Let_FetchBufferSize
    
    Const FUNCTION_NAME = "P_LET FetchBufferSize"
    
    'let property
    m_lFetchBufferSize = lNewFetchBufferSize
    
    Exit Property
    
err_Let_FetchBufferSize:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Property
Public Property Get tableFilter() As String
    On Error GoTo err_Get_TableFilter
    
    Const FUNCTION_NAME = "P_Get tableFilter"
    
    ' get property
    tableFilter = m_sTableFilter
    
    Exit Property
    
err_Get_TableFilter:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Property
Public Property Let tableFilter(sNewTableFilter As String)
    On Error GoTo err_Let_TableFilter
    
    Const FUNCTION_NAME = "P_LET TableFilter"
    
    'let property
    m_sTableFilter = sNewTableFilter
    
    Exit Property
    
err_Let_TableFilter:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Property
Public Property Get expandedNodes() As String
    On Error GoTo err_Get_ExpandedNodes
    
    Const FUNCTION_NAME = "P_Get expandedNodes"
    
    ' get property
    expandedNodes = m_sExpandedNodes
    
    Exit Property
    
err_Get_ExpandedNodes:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Property
Public Property Let expandedNodes(sNewExpandedNodes As String)
    On Error GoTo err_Let_ExpandedNodes
    
    Const FUNCTION_NAME = "P_LET ExpandedNodes"
    
    'let property
    m_sExpandedNodes = sNewExpandedNodes
    
    Exit Property
    
err_Let_ExpandedNodes:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Property
Public Function loadUserProfile(connection As SQLStudioDBLayer.connection) As Boolean
    On Error GoTo ErrLoadUserProfile
    
    Const FUNCTION_NAME = "LoadUserProfile"
    
    Dim sUserProfile        As String
    Dim NextToken           As String
    Dim sFont               As String
    Dim sTableFilter        As String
    Dim bTableFilterLoaded  As Boolean
    
    'inits
    loadUserProfile = False
        
    ' Get user profile description
    If Not getUserProfileDescription(connection, sUserProfile) Then Exit Function
    
    'Version
    m_oComFunc.GetNextToken sUserProfile, NextToken, m_oComFunc.GetTokenSeperator(qplObjectLevel1)
    If Len(NextToken) > 0 Then
    
       If IsNumeric(NextToken) Then
       
            m_lVersion = CLng(NextToken)
       Else
            m_lVersion = 0
            'Exit because ist an very,very old userprofile
            Exit Function
       End If
    Else
        m_lVersion = 0
        'load local settings for new user profile
        
        'read local root from registry
        m_sLocalRoot = readLocalRoot
        
        Exit Function
    End If
        
    ' Get selectTableTypes settings
    m_oComFunc.GetNextToken sUserProfile, NextToken, m_oComFunc.GetTokenSeperator(qplObjectLevel1)
    m_oSelectTableTypes.getTableTypesFromDescription NextToken
    
    ' get Password Options
    m_oComFunc.GetNextToken sUserProfile, NextToken, m_oComFunc.GetTokenSeperator(qplObjectLevel1)
    m_oPasswordOptions.getPasswordOptionsFromDescription NextToken
       
    'Font
    getFont m_typeUserFont, sUserProfile
        
    'ReplaceNonChars
    m_oComFunc.GetNextToken sUserProfile, NextToken, m_oComFunc.GetTokenSeperator(qplObjectLevel1)
    m_bReplaceNonCharsInLongColumn = m_oComFunc.getBoolValueFromToken(NextToken)
        
    'Confirmation
    m_oComFunc.GetNextToken sUserProfile, NextToken, m_oComFunc.GetTokenSeperator(qplObjectLevel1)
    m_bConfirmation = m_oComFunc.getBoolValueFromToken(NextToken)
    
    'tableFilter
    bTableFilterLoaded = False
    m_oComFunc.GetNextToken sUserProfile, NextToken, m_oComFunc.GetTokenSeperator(qplObjectLevel1)
    If Len(NextToken) > 0 Then
    
        sTableFilter = NextToken
        While Len(sTableFilter) > 0
            m_oComFunc.GetNextToken sTableFilter, NextToken, m_oComFunc.GetTokenSeperator(qplObjectLevel2)
           
            If bTableFilterLoaded = False Then
            
                bTableFilterLoaded = True
                m_sTableFilter = NextToken
            Else
                m_colTableFilter.add NextToken
            End If
        Wend
    End If
    
    'Font Reports
    getFont m_typeReportFont, sUserProfile
    
    'Limit for Long
    m_oComFunc.GetNextToken sUserProfile, NextToken, m_oComFunc.GetTokenSeperator(qplObjectLevel1)
    If Len(NextToken) > 0 Then
    
        m_lLimitForLongColumn = Val(Trim$(NextToken))
    Else
        m_lLimitForLongColumn = 1024
    End If
    
    'Fetch Page Size
    m_oComFunc.GetNextToken sUserProfile, NextToken, m_oComFunc.GetTokenSeperator(qplObjectLevel1)
    If Len(NextToken) > 0 Then
    
        m_lFetchBlockSize = Val(Trim$(NextToken))
    Else
        m_lFetchBlockSize = 512
    End If
    
    'Fix Value
    m_lFetchBlockSize = 512
    
    'Fetch Buffersize
    m_oComFunc.GetNextToken sUserProfile, NextToken, m_oComFunc.GetTokenSeperator(qplObjectLevel1)
    If Len(NextToken) > 0 Then
    
        m_lFetchBufferSize = Val(Trim$(NextToken))
    Else
        m_lFetchBufferSize = 2048
    End If
    
    'Fix Value
    m_lFetchBufferSize = 2048

    'Expanded Nodes
    m_sExpandedNodes = ""
    m_oComFunc.GetNextToken sUserProfile, NextToken, m_oComFunc.GetTokenSeperator(qplObjectLevel1)
    If Len(NextToken) > 0 Then
    
        m_sExpandedNodes = NextToken
    Else
        m_sExpandedNodes = ""
    End If
    
    'RestoreCatalogState
    m_oComFunc.GetNextToken sUserProfile, NextToken, m_oComFunc.GetTokenSeperator(qplObjectLevel1)
    m_bRestoreCatalogState = m_oComFunc.getBoolValueFromToken(NextToken)
    
    'Get SQLStudioObjects Options
    m_oComFunc.GetNextToken sUserProfile, NextToken, m_oComFunc.GetTokenSeperator(qplObjectLevel1)
    m_oAppManagment.getStudioObjectsFromDescription NextToken
    
   'ClippedResultView
    m_oComFunc.GetNextToken sUserProfile, NextToken, m_oComFunc.GetTokenSeperator(qplObjectLevel1)
    m_bClippedResultView = m_oComFunc.getBoolValueFromToken(NextToken)
    
    'EscapeCharacter
    m_oComFunc.GetNextToken sUserProfile, NextToken, m_oComFunc.GetTokenSeperator(qplObjectLevel1)
    If Len(NextToken) > 0 Then
    
        m_sEscapeCharacter = NextToken
    Else
        m_sEscapeCharacter = "\"
    End If
    
    'RepOfNullValue
    m_oComFunc.GetNextToken sUserProfile, NextToken, m_oComFunc.GetTokenSeperator(qplObjectLevel1)
    If Len(NextToken) > 0 Then
    
        m_sRepOfNullValue = NextToken
    Else
        m_sRepOfNullValue = "?"
    End If
    
    'QBEReadOnly
    m_oComFunc.GetNextToken sUserProfile, NextToken, m_oComFunc.GetTokenSeperator(qplObjectLevel1)
    m_bQBEReadOnly = m_oComFunc.getBoolValueFromToken(NextToken)
    
    'ForTextColor
    m_oComFunc.GetNextToken sUserProfile, NextToken, m_oComFunc.GetTokenSeperator(qplObjectLevel1)
    If Len(NextToken) > 0 Then
    
        m_lForTextColor = Val(Trim$(NextToken))
    Else
        m_lForTextColor = 0
    End If
    
    'm_lProtTextColor
    m_oComFunc.GetNextToken sUserProfile, NextToken, m_oComFunc.GetTokenSeperator(qplObjectLevel1)
    If Len(NextToken) > 0 Then
    
        m_lProtTextColor = Val(Trim$(NextToken))
    Else
        m_lProtTextColor = 12632256
    End If
    
    'm_lHighlightColor
    m_oComFunc.GetNextToken sUserProfile, NextToken, m_oComFunc.GetTokenSeperator(qplObjectLevel1)
    If Len(NextToken) > 0 Then
    
        m_lHighlightColor = Val(Trim$(NextToken))
    Else
        m_lHighlightColor = RGB(0, 0, 255)
    End If
    
    'm_sLocalRoot
    'read the local root from the database userprofile
    'to keep token stream valid, even the value is empty
    m_oComFunc.GetNextToken sUserProfile, NextToken, m_oComFunc.GetTokenSeperator(qplObjectLevel1)
    'now read local root from registry
    m_sLocalRoot = readLocalRoot
    'if there is no local root in the registry take the old one of the database, if one exits
    If Len(m_sLocalRoot) < 1 And Len(NextToken) > 0 Then
    
        m_sLocalRoot = NextToken
    End If
        
    'flag, if input of filter box for the catalog table folder is converted to uppercase
    m_oComFunc.GetNextToken sUserProfile, NextToken, m_oComFunc.GetTokenSeperator(qplObjectLevel1)
    m_bCMFilterInputUpper = m_oComFunc.getBoolValueFromToken(NextToken)
    
    'flag, if columns are seperated with tabs when copied to clipboard
    m_oComFunc.GetNextToken sUserProfile, NextToken, m_oComFunc.GetTokenSeperator(qplObjectLevel1)
    m_bCopyColumsTabSep = m_oComFunc.getBoolValueFromToken(NextToken)
    
    'flag, if identifiers in create dialogs are case sensitiv
    m_oComFunc.GetNextToken sUserProfile, NextToken, m_oComFunc.GetTokenSeperator(qplObjectLevel1)
    m_bIdentifiersCaseSensitiv = m_oComFunc.getBoolValueFromToken(NextToken)
    
    'flag, if result is copied with column header
    m_oComFunc.GetNextToken sUserProfile, NextToken, m_oComFunc.GetTokenSeperator(qplObjectLevel1)
    m_bCopyResultWithHeader = m_oComFunc.getBoolValueFromToken(NextToken)
        
    'set rc
    loadUserProfile = True
    
    Exit Function
    
ErrLoadUserProfile:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Function
Public Function saveUserProfile(oConnection As SQLStudioDBLayer.connection) As Boolean
    On Error GoTo errSaveUserProfile
    
    Const FUNCTION_NAME = "saveUserProfile"
    
    MsgBox LoadResString(301), vbCritical
    
    Exit Function
    
errSaveUserProfile:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Function
Public Function loadUserProfileFromReg(hiddenProps As Boolean) As Boolean
    On Error GoTo errLoadUserProfileFromReg
    
    Const FUNCTION_NAME = "loadUserProfileFromReg"
    
    Dim sUserProfile        As String
    Dim NextToken           As String
    Dim sFont               As String
    Dim sTableFilter        As String
    Dim bTableFilterLoaded  As Boolean
    
    'inits
    loadUserProfileFromReg = False
    
    If hiddenProps Then
        'Font
        NextToken = readStringValue(STD_FONT)
        getFontFromReg m_typeUserFont, NextToken
        
        NextToken = readStringValue(FONT_REPORT)
        getFontFromReg m_typeReportFont, NextToken
        
        'Expanded Nodes
        NextToken = readStringValue(STD_EXPANDED_NODES)
        If Len(NextToken) > 0 Then
        
            m_sExpandedNodes = NextToken
        Else
            m_sExpandedNodes = ""
        End If
        
        'ForTextColor
        NextToken = readStringValue(DSQL_FORTEXTCOLOR)
        If Len(NextToken) > 0 Then
        
            m_lForTextColor = Val(Trim$(NextToken))
        Else
            m_lForTextColor = 0
        End If
           
        'm_lHighlightColor
        NextToken = readStringValue(DSQL_HIGHLIGHTCOLOR)
        If Len(NextToken) > 0 Then
        
            m_lHighlightColor = Val(Trim$(NextToken))
        Else
            m_lHighlightColor = RGB(0, 0, 255)
        End If
        
        'tableFilter
        bTableFilterLoaded = False
        NextToken = readStringValue(STD_TABLEFILTER)
        If Len(NextToken) > 0 Then
        
            sTableFilter = NextToken
            While Len(sTableFilter) > 0
                m_oComFunc.GetNextToken sTableFilter, NextToken, m_oComFunc.GetTokenSeperator(qplObjectLevel2)
               
                If bTableFilterLoaded = False Then
                
                    bTableFilterLoaded = True
                    m_sTableFilter = NextToken
                Else
                    m_colTableFilter.add NextToken
                End If
            Wend
        End If
    End If
            
    ' Get selectTableTypes settings
    NextToken = readStringValue(TABLETYPES)
    m_oSelectTableTypes.getTableTypesFromDescription NextToken
    
    ' get Password Options
    NextToken = readStringValue(STORE_PASSWORDS)
    m_oPasswordOptions.getPasswordOptionsFromDescription NextToken
       
            
    'ReplaceNonChars
    NextToken = readStringValue(REPLACE_NON_CHARS)
    m_bReplaceNonCharsInLongColumn = m_oComFunc.getBoolValueFromToken(NextToken)
        
    'Confirmation
    NextToken = readStringValue(STDOBJ_CONFIRMATION)
    m_bConfirmation = m_oComFunc.getBoolValueFromToken(NextToken)
       
    
    'Limit for Long
    NextToken = readStringValue(LIMIT_FORLONG)
    If Len(NextToken) > 0 Then
    
        m_lLimitForLongColumn = Val(Trim$(NextToken))
    Else
        m_lLimitForLongColumn = 1024
    End If
    
        
    'RestoreCatalogState
    NextToken = readStringValue(RESTORE_CATALOG)
    m_bRestoreCatalogState = m_oComFunc.getBoolValueFromToken(NextToken)
    
    'Get SQLStudioObjects Options
    NextToken = readStringValue(OBJECT_SETTINGS)
    m_oAppManagment.getStudioObjectsFromDescription NextToken
    
   'ClippedResultView
    NextToken = readStringValue(CLIPPED_RESULTVIEW)
    m_bClippedResultView = m_oComFunc.getBoolValueFromToken(NextToken)
    
    'EscapeCharacter
    NextToken = readStringValue(ESCAPE_CHAR)
    If Len(NextToken) > 0 Then
    
        m_sEscapeCharacter = NextToken
    Else
        m_sEscapeCharacter = "\"
    End If
    
    'RepOfNullValue
    NextToken = readStringValue(REP_NULLVALUE)
    If Len(NextToken) > 0 Then
    
        m_sRepOfNullValue = NextToken
    Else
        m_sRepOfNullValue = "?"
    End If
    
    'QBEReadOnly
    NextToken = readStringValue(QBE_READONLY)
    m_bQBEReadOnly = m_oComFunc.getBoolValueFromToken(NextToken)
    
    'read local root from registry
    m_sLocalRoot = readStringValue(STD_LOCALROOT)
        
    'flag, if input of filter box for the catalog table folder is converted to uppercase
    NextToken = readStringValue(FILTERINPUT_UPPER)
    m_bCMFilterInputUpper = m_oComFunc.getBoolValueFromToken(NextToken)
    
      
    'flag, if columns are seperated with tabs when copied to clipboard
    NextToken = readStringValue(COPY_TABSEP)
    m_bCopyColumsTabSep = m_oComFunc.getBoolValueFromToken(NextToken)
    
    'flag, if identifiers in create dialogs are case sensitiv
    NextToken = readStringValue(ID_CASE_SENSITIV)
    m_bIdentifiersCaseSensitiv = m_oComFunc.getBoolValueFromToken(NextToken)
    
    'flag, if result is copied with column header
    NextToken = readStringValue(COPY_RESULT_HEADER)
    m_bCopyResultWithHeader = m_oComFunc.getBoolValueFromToken(NextToken)
        
    'set rc
    loadUserProfileFromReg = True
    
    Exit Function
    
errLoadUserProfileFromReg:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Function
Public Function saveUserProfileInReg() As Boolean
    On Error GoTo errSaveUserProfileInReg
    
    Const FUNCTION_NAME = "saveUserProfileInReg"
        
    Dim userProfile                     As String
    Dim SelectTableTypesDescription     As String
    Dim sPasswordOptions                As String
    Dim sSQLStudioObjects               As String
    Dim lRun                            As Long
    
    'rc
    saveUserProfileInReg = False
    
    'init
    sSQLStudioObjects = ""
                  
                
    'set SelectTableTypes settings
    m_oSelectTableTypes.getDescriptionFromTableTypes SelectTableTypesDescription
    writeStringValue TABLETYPES, SelectTableTypesDescription
    
    'set StorePassword settings
    m_oPasswordOptions.getDescriptionFromPasswordOptions sPasswordOptions
    writeStringValue STORE_PASSWORDS, sPasswordOptions
                              
    'Font
    writeStringValue STD_FONT, m_typeUserFont.name + m_oComFunc.GetTokenSeperator(qplObjectLevel2) _
                              + m_oComFunc.makeBoolToNumericString(m_typeUserFont.FontBold) + m_oComFunc.GetTokenSeperator(qplObjectLevel2) _
                              + m_oComFunc.makeBoolToNumericString(m_typeUserFont.FontItalic) + m_oComFunc.GetTokenSeperator(qplObjectLevel2) _
                              + Trim$(Str$(m_typeUserFont.FontSize)) + m_oComFunc.GetTokenSeperator(qplObjectLevel2) _
                              + m_oComFunc.makeBoolToNumericString(m_typeUserFont.FontStrikethrough) + m_oComFunc.GetTokenSeperator(qplObjectLevel2) _
                              + m_oComFunc.makeBoolToNumericString(m_typeUserFont.FontUnderline) + m_oComFunc.GetTokenSeperator(qplObjectLevel2) _
                    
    
        
    'Replace non chars
    writeStringValue REPLACE_NON_CHARS, m_oComFunc.makeBoolToNumericString(m_bReplaceNonCharsInLongColumn)
    
    
    'Confirmation
    writeStringValue STDOBJ_CONFIRMATION, m_oComFunc.makeBoolToNumericString(m_bConfirmation)
                   
                   
    'TableFilter
    userProfile = Trim$(m_sTableFilter) + m_oComFunc.GetTokenSeperator(qplObjectLevel2)
    For lRun = 1 To m_colTableFilter.count
    
        userProfile = userProfile + Trim$(m_colTableFilter.item(lRun)) + _
                      m_oComFunc.GetTokenSeperator(qplObjectLevel2)
    Next
    writeStringValue STD_TABLEFILTER, userProfile
    
    
    'Font Report
    userProfile = m_typeReportFont.name + m_oComFunc.GetTokenSeperator(qplObjectLevel2) _
                    + m_oComFunc.makeBoolToNumericString(m_typeReportFont.FontBold) + m_oComFunc.GetTokenSeperator(qplObjectLevel2) _
                    + m_oComFunc.makeBoolToNumericString(m_typeReportFont.FontItalic) + m_oComFunc.GetTokenSeperator(qplObjectLevel2) _
                    + Trim$(Str$(m_typeReportFont.FontSize)) + m_oComFunc.GetTokenSeperator(qplObjectLevel2) _
                    + m_oComFunc.makeBoolToNumericString(m_typeReportFont.FontStrikethrough) + m_oComFunc.GetTokenSeperator(qplObjectLevel2) _
                    + m_oComFunc.makeBoolToNumericString(m_typeReportFont.FontUnderline) + m_oComFunc.GetTokenSeperator(qplObjectLevel2) _
                    
    writeStringValue FONT_REPORT, userProfile
    
    writeStringValue LIMIT_FORLONG, Trim$(Str$(m_lLimitForLongColumn))
                      
    'Expanded Nodes
    writeStringValue STD_EXPANDED_NODES, m_sExpandedNodes
                      
    'RestoreCatalogState
    writeStringValue RESTORE_CATALOG, m_oComFunc.makeBoolToNumericString(m_bRestoreCatalogState)
                   
                   
    'set SQLStudio ObjectsSettings
    m_oAppManagment.getDescriptionFromStudioObjects sSQLStudioObjects
    writeStringValue OBJECT_SETTINGS, sSQLStudioObjects
    
    
    'ClippedResultView
    writeStringValue CLIPPED_RESULTVIEW, m_oComFunc.makeBoolToNumericString(m_bClippedResultView)
                   
                   
    'EscapeCharacter
    writeStringValue ESCAPE_CHAR, m_sEscapeCharacter
                   
                   
    'Representation Of Null Value
    writeStringValue REP_NULLVALUE, m_sRepOfNullValue
                   
    'QBEReadOnly
    writeStringValue QBE_READONLY, m_oComFunc.makeBoolToNumericString(m_bQBEReadOnly)
                                     
    'ForTextColor
    writeStringValue DSQL_FORTEXTCOLOR, Trim$(Str$(m_lForTextColor))
                                         
    'HighlightColor
    writeStringValue DSQL_HIGHLIGHTCOLOR, Trim$(Str$(m_lHighlightColor))
                   
    'Local Root
    writeStringValue STD_LOCALROOT, m_sLocalRoot
                   
    'input of filter box for the catalog table folder is converted to uppercase
    writeStringValue FILTERINPUT_UPPER, m_oComFunc.makeBoolToNumericString(m_bCMFilterInputUpper)
                   
                   
    'if rows are copied in the result dailog, they are seperated with tabs
    writeStringValue COPY_TABSEP, m_oComFunc.makeBoolToNumericString(m_bCopyColumsTabSep)
                   
    
    'if column names in create table dialog are case sensitiv
    writeStringValue ID_CASE_SENSITIV, m_oComFunc.makeBoolToNumericString(m_bIdentifiersCaseSensitiv)
                   
                   
    'if result is copied with column header
    writeStringValue COPY_RESULT_HEADER, m_oComFunc.makeBoolToNumericString(m_bCopyResultWithHeader)
    
    'delete old key of local folder
    deleteRegEntry LOCAL_ROOT + "\" + NOVERSIONDEP
    deleteRegEntry LOCAL_ROOT
        
    'rc
    saveUserProfileInReg = True
    
    Exit Function
    
errSaveUserProfileInReg:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Function
'hidden user profile data is e.g font information
Public Function saveHiddenUserProperties(connection As SQLStudioDBLayer.connection) As Boolean
    On Error GoTo errSaveHiddenUserProperties
    
    Const FUNCTION_NAME = "saveHiddenUserProperties"
    
    MsgBox LoadResString(301), vbCritical
    
    Exit Function
    
errSaveHiddenUserProperties:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Function
Private Function getUserProfileDescription(oConnection As SQLStudioDBLayer.connection, _
                                           sUserProfile As String) As Boolean
    On Error GoTo errGetUserProfileDescription

    Const FUNCTION_NAME = "GetUserProfileDescription"
    
    '=varibles==========================================
    Dim oResult      As New SQLStudioDBLayer.result
    '===================================================
    
    'rc
    getUserProfileDescription = False
    
    'init
    sUserProfile = ""
       
    Set oResult.connection = oConnection
    
    '  Open result
    If Not oResult.OpenResult("SELECT PROFILE FROM SYSQP_USER_PROFILES WHERE " + Chr$(34) + "UID" + Chr$(34) + " = USERGROUP ", Internal) _
       Then Exit Function
    
    ' get next row
    If Not oResult.fetch Then Exit Function
    
    If Not oResult.NoRows Then
    
        If Not oResult.GetData() Then Exit Function
        'set user profile
        sUserProfile = oResult.Columns.item(1).colValue
    End If
        
    getUserProfileDescription = True    'set rc
    
    Exit Function
    
errGetUserProfileDescription:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Function
'=========================================================================================
'    function:      Class_Initialize
'    description:   Occurs when an application creates an instance of a Form,
'                   MDIForm, User control, Property Page, Webclass, DHTML Page Designer, or class.
'
'    arguments:     /
'
'    return value:  /
'
'=========================================================================================
Private Sub Class_Initialize()
    On Error GoTo ErrClass_Initialize

    Const FUNCTION_NAME = "Class_Initialize"
    
    Dim lRun          As Long
    
    m_typeUserFont.name = "MS Sans Serif"
    m_typeUserFont.FontBold = False
    m_typeUserFont.FontItalic = False
    m_typeUserFont.FontSize = 12
    m_typeUserFont.FontStrikethrough = False
    m_typeUserFont.FontUnderline = False
    
    m_typeReportFont.name = "MS Sans Serif"
    m_typeReportFont.FontBold = False
    m_typeReportFont.FontItalic = False
    m_typeReportFont.FontSize = 9
    m_typeReportFont.FontStrikethrough = False
    m_typeReportFont.FontUnderline = False
        
    m_lLimitForLongColumn = 1024
    m_lFetchBlockSize = 512
    m_lFetchBufferSize = 2048
    m_bRestoreCatalogState = False
    m_bClippedResultView = True
    m_sTableFilter = ""
    m_sExpandedNodes = ""
    
    m_bConfirmation = True
    m_bQBEReadOnly = True
    
    m_sEscapeCharacter = "\"
    m_sRepOfNullValue = "?"
    
    m_lAppVersion = 70200
    m_lVersion = m_lAppVersion
    
    m_bIdentifiersCaseSensitiv = False

    For lRun = 1 To m_colTableFilter.count
    
        m_colTableFilter.remove 1
    Next
    
    m_lForTextColor = 0
    m_lProtTextColor = 12632256
    m_lHighlightColor = RGB(0, 0, 255)
    
    m_sLocalRoot = ""
    
    'input of filter box for the catalog table folder is converted to uppercase
    m_bCMFilterInputUpper = False
    
    m_bCopyColumsTabSep = False
    m_bCopyResultWithHeader = False
    m_bIdentifiersCaseSensitiv = False
    
    Exit Sub
    
ErrClass_Initialize:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Sub
Private Function getFont(pFont As Font, userProfile As String)
    On Error GoTo errGetFont

    Const FUNCTION_NAME = "GetFont"
    
    Dim NextToken       As String
    Dim sFont           As String


    'Font
    m_oComFunc.GetNextToken userProfile, NextToken, m_oComFunc.GetTokenSeperator(qplObjectLevel1)
    sFont = NextToken
    
    If Len(sFont) > 0 Then
        m_oComFunc.GetNextToken sFont, NextToken, m_oComFunc.GetTokenSeperator(qplObjectLevel2)
        pFont.name = NextToken
    End If
    
    If Len(sFont) > 0 Then
        m_oComFunc.GetNextToken sFont, NextToken, m_oComFunc.GetTokenSeperator(qplObjectLevel2)
        pFont.FontBold = m_oComFunc.getBoolValueFromToken(NextToken)
    End If

    If Len(sFont) > 0 Then
        m_oComFunc.GetNextToken sFont, NextToken, m_oComFunc.GetTokenSeperator(qplObjectLevel2)
        pFont.FontItalic = m_oComFunc.getBoolValueFromToken(NextToken)
    End If


    If Len(sFont) > 0 Then
        m_oComFunc.GetNextToken sFont, NextToken, m_oComFunc.GetTokenSeperator(qplObjectLevel2)
        If Len(NextToken) > 0 Then pFont.FontSize = Val(Trim(NextToken))
    End If
    
    If Len(sFont) > 0 Then
        m_oComFunc.GetNextToken sFont, NextToken, m_oComFunc.GetTokenSeperator(qplObjectLevel2)
        pFont.FontStrikethrough = m_oComFunc.getBoolValueFromToken(NextToken)
    End If
    
    If Len(sFont) > 0 Then
        m_oComFunc.GetNextToken sFont, NextToken, m_oComFunc.GetTokenSeperator(qplObjectLevel2)
        pFont.FontUnderline = m_oComFunc.getBoolValueFromToken(NextToken)
    End If
    
    
    Exit Function
    
errGetFont:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Function
Private Function getFontFromReg(pFont As Font, sFont As String)
    On Error GoTo errGetFont

    Const FUNCTION_NAME = "GetFont"
    
    Dim NextToken       As String
    
    
    If Len(sFont) > 0 Then
        m_oComFunc.GetNextToken sFont, NextToken, m_oComFunc.GetTokenSeperator(qplObjectLevel2)
        pFont.name = NextToken
    End If
    
    If Len(sFont) > 0 Then
        m_oComFunc.GetNextToken sFont, NextToken, m_oComFunc.GetTokenSeperator(qplObjectLevel2)
        pFont.FontBold = m_oComFunc.getBoolValueFromToken(NextToken)
    End If

    If Len(sFont) > 0 Then
        m_oComFunc.GetNextToken sFont, NextToken, m_oComFunc.GetTokenSeperator(qplObjectLevel2)
        pFont.FontItalic = m_oComFunc.getBoolValueFromToken(NextToken)
    End If


    If Len(sFont) > 0 Then
        m_oComFunc.GetNextToken sFont, NextToken, m_oComFunc.GetTokenSeperator(qplObjectLevel2)
        If Len(NextToken) > 0 Then pFont.FontSize = Val(Trim(NextToken))
    End If
    
    If Len(sFont) > 0 Then
        m_oComFunc.GetNextToken sFont, NextToken, m_oComFunc.GetTokenSeperator(qplObjectLevel2)
        pFont.FontStrikethrough = m_oComFunc.getBoolValueFromToken(NextToken)
    End If
    
    If Len(sFont) > 0 Then
        m_oComFunc.GetNextToken sFont, NextToken, m_oComFunc.GetTokenSeperator(qplObjectLevel2)
        pFont.FontUnderline = m_oComFunc.getBoolValueFromToken(NextToken)
    End If
    
    
    Exit Function
    
errGetFont:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Function
Public Function getTableFilterList(lIndex As Long) As String
    On Error GoTo errGetTableFilterList
    
    Const FUNCTION_NAME = "GetTableFilterList"
    
    
    If lIndex < 1 Or lIndex > m_colTableFilter.count Then
        
        getTableFilterList = ""
        Exit Function
    End If
    
    getTableFilterList = m_colTableFilter.item(lIndex)
        
    Exit Function
    
errGetTableFilterList:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Function
Public Function addTableFilterList(sNewFilter As String)
    On Error GoTo errAddTableFilterList
    
    Const FUNCTION_NAME = "AddTableFilterList"
    
    Dim lRun As Long
    Dim bFound As Boolean
    
    'Init
    bFound = False
    
    While m_colTableFilter.count > 10 And m_colTableFilter.count > 0
    
        m_colTableFilter.remove m_colTableFilter.count
    Wend
    
    For lRun = 1 To m_colTableFilter.count
        If m_colTableFilter.item(lRun) = sNewFilter Then bFound = True
    Next
        
    If bFound = False Then
        
        m_colTableFilter.add sNewFilter
    End If
    
    bFound = True
        
    Exit Function
    
errAddTableFilterList:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Function

Public Function clearFilterList()
    On Error GoTo ErrClearFilterList
    
    Const FUNCTION_NAME = "ClearFilterList"
    
    Dim lRun As Long
      
    While m_colTableFilter.count > 0
    
        m_colTableFilter.remove 1
    Wend
        
    Exit Function
    
ErrClearFilterList:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Function
Public Property Get escapeCharacter() As String
    On Error GoTo err_Get_EscapeCharacter
    
    Const FUNCTION_NAME = "P_Get escapeCharacter "
    
    ' get property
    escapeCharacter = m_sEscapeCharacter
    
    Exit Property
    
err_Get_EscapeCharacter:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Property
Public Property Let escapeCharacter(sNewEscapeCharacter As String)
    On Error GoTo err_Let_EscapeCharacter
    
    Const FUNCTION_NAME = "P_LET EscapeCharacter "
    
    'let property
    m_sEscapeCharacter = sNewEscapeCharacter
    
    Exit Property
    
err_Let_EscapeCharacter:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Property
Public Property Get repOfNullValue() As String
    On Error GoTo err_Get_RepOfNullValue
    
    Const FUNCTION_NAME = "P_Get repOfNullValue "
    
    ' get property
    repOfNullValue = m_sRepOfNullValue
    
    Exit Property
    
err_Get_RepOfNullValue:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Property
Public Property Let repOfNullValue(sNewRepOfNullValue As String)
    On Error GoTo err_Let_RepOfNullValue
    
    Const FUNCTION_NAME = "P_LET RepOfNullValue "
    
    'let property
    m_sRepOfNullValue = sNewRepOfNullValue
    
    Exit Property
    
err_Let_RepOfNullValue:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Property
Public Property Get qbeReadOnly() As Boolean
    On Error GoTo err_Get_QBEReadOnly
    
    Const FUNCTION_NAME = "P_Get qbeReadOnly"
    
    ' get property
    qbeReadOnly = m_bQBEReadOnly
    
    Exit Property
    
err_Get_QBEReadOnly:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Property
Public Property Let qbeReadOnly(bNewQBEReadOnly As Boolean)
    On Error GoTo err_Let_QBEReadOnly
    
    Const FUNCTION_NAME = "P_LET QBEReadOnly"
    
    'let property
    m_bQBEReadOnly = bNewQBEReadOnly
    
    Exit Property
    
err_Let_QBEReadOnly:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Property

Public Property Let forTextColor(lNewForTextColor As Long)
    On Error GoTo err_Let_ForTextColor
    
    Const FUNCTION_NAME = "P_LET ForTextColor"
    
    'let property
    m_lForTextColor = lNewForTextColor
    
    Exit Property
    
err_Let_ForTextColor:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Property
Public Property Get forTextColor() As Long
    On Error GoTo err_Get_ForTextColor
    
    Const FUNCTION_NAME = "P_Get forTextColor"
    
    ' get property
    forTextColor = m_lForTextColor
    
    Exit Property
    
err_Get_ForTextColor:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Property
Public Property Let highlightColor(lNewHighlightColor As Long)
    On Error GoTo err_Let_HighlightColor
    
    Const FUNCTION_NAME = "P_LET HighlightColor"
    
    'let property
    m_lHighlightColor = lNewHighlightColor
    
    Exit Property
    
err_Let_HighlightColor:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Property
Public Property Get highlightColor() As Long
    On Error GoTo err_Get_HighlightColor
    
    Const FUNCTION_NAME = "P_Get highlightColor"
    
    ' get property
    highlightColor = m_lHighlightColor
    
    Exit Property
    
err_Get_HighlightColor:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Property
Public Property Get localRoot() As String
    On Error GoTo err_Get_LocalRoot
    
    Const FUNCTION_NAME = "P_Get localRoot"
    
    ' get property
    localRoot = m_sLocalRoot
    
    Exit Property
    
err_Get_LocalRoot:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Property
Public Property Let localRoot(sNewLocalRoot As String)
    On Error GoTo err_Let_LocalRoot
    
    Const FUNCTION_NAME = "P_LET LocalRoot"
    
    'let property
    m_sLocalRoot = sNewLocalRoot
    
    Exit Property
    
err_Let_LocalRoot:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Property
'=========================================================================================
'    property:      CMFilterInputUpper
'    description:   get if input of filter box for
'                   the catalog table folder is converted to uppercase
'    arguments:     /
'
'    return value:  boolean
'
'=========================================================================================
Public Property Get cmFilterInputUpper() As Boolean
    On Error GoTo err_Get_CMFilterInputUpper
    
    Const FUNCTION_NAME = "P_Get cmFilterInputUpper"
    
    ' get property
    cmFilterInputUpper = m_bCMFilterInputUpper
    
    Exit Property
    
err_Get_CMFilterInputUpper:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Property
'=========================================================================================
'    property:      cmFilterInputUpper
'    description:   set if input of filter box for
'                   the catalog table folder is converted to uppercase
'    arguments:     bNewCMFilterInputUpper
'
'    return value:  /
'
'=========================================================================================
Public Property Let cmFilterInputUpper(bNewCMFilterInputUpper As Boolean)
    On Error GoTo err_Let_CMFilterInputUpper
    
    Const FUNCTION_NAME = "P_LET cmFilterInputUpper"
    
    'let property
    m_bCMFilterInputUpper = bNewCMFilterInputUpper
    
    Exit Property
    
err_Let_CMFilterInputUpper:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Property
'=========================================================================================
'    property:      copyColumsTabSep
'    description:   if rows are copied in the result dailog, they are seperated with tabs
'    arguments:     /
'
'    return value:  boolean
'
'=========================================================================================
Public Property Get copyColumsTabSep() As Boolean
    On Error GoTo err_Get_CopyColumsTabSep
    
    Const FUNCTION_NAME = "P_Get copyColumsTabSep"
    
    'get property
    copyColumsTabSep = m_bCopyColumsTabSep
    
    Exit Property
    
err_Get_CopyColumsTabSep:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Property
'=========================================================================================
'    property:      copyColumsTabSep
'    description:   if rows are copied in the result dailog, they are seperated with tabs'
'    arguments:     bNewCopyColumsTabSep
'
'    return value:  /
'
'=========================================================================================
Public Property Let copyColumsTabSep(bNewCopyColumsTabSep As Boolean)
    On Error GoTo err_Let_CopyColumsTabSep
    
    Const FUNCTION_NAME = "P_LET copyColumsTabSep"
    
    'let property
    m_bCopyColumsTabSep = bNewCopyColumsTabSep
    
    Exit Property
    
err_Let_CopyColumsTabSep:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Property
'=========================================================================================
'    property:      createTableColumnsCaseSensitiv
'
'    !!! This property is not valid any more '''
'    !!! Just kept for binary compatibility
'
'    return value:  boolean
'
'=========================================================================================
Public Property Get createTableColumnsCaseSensitiv() As Boolean
    On Error GoTo err_Get_createTableColumnsCaseSensitiv
    
    Const FUNCTION_NAME = "P_Get createTableColumnsCaseSensitiv"
        
    MsgBox LoadResString(416)
    
    Exit Property
    
err_Get_createTableColumnsCaseSensitiv:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Property
Public Property Let createTableColumnsCaseSensitiv(bNewCreateTableColumnsCaseSensitiv As Boolean)
    On Error GoTo err_Let_createTableColumnsCaseSensitiv
    
    Const FUNCTION_NAME = "P_LET createTableColumnsCaseSensitiv"
    
    MsgBox LoadResString(300)
    
    Exit Property
    
err_Let_createTableColumnsCaseSensitiv:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Property
'=========================================================================================
'    property:      identifiersCaseSensitiv
'
'    return value:  boolean
'
'=========================================================================================
Public Property Get identifiersCaseSensitiv() As Boolean
    On Error GoTo err_Get_identifiersCaseSensitiv
    
    Const FUNCTION_NAME = "P_Get identifiersCaseSensitiv"
           
    ' get property
    identifiersCaseSensitiv = m_bIdentifiersCaseSensitiv
    
    Exit Property
    
err_Get_identifiersCaseSensitiv:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Property
Public Property Let identifiersCaseSensitiv(bNewidentifiersCaseSensitiv As Boolean)
    On Error GoTo err_Let_identifiersCaseSensitiv
    
    Const FUNCTION_NAME = "P_LET identifiersCaseSensitiv"
    
    'let property
    m_bIdentifiersCaseSensitiv = bNewidentifiersCaseSensitiv
    
    Exit Property
    
err_Let_identifiersCaseSensitiv:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Property
Public Property Get copyResultWithHeader() As Boolean
    On Error GoTo err_Get_copyResultWithHeader
    
    Const FUNCTION_NAME = "P_Get copyResultWithHeader"
    
    ' get property
    copyResultWithHeader = m_bCopyResultWithHeader
    
    Exit Property
    
err_Get_copyResultWithHeader:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Property
Public Property Let copyResultWithHeader(bNewcopyResultWithHeader As Boolean)
    On Error GoTo err_Let_copyResultWithHeader
    
    Const FUNCTION_NAME = "P_LET copyResultWithHeader"
    
    'let property
    m_bCopyResultWithHeader = bNewcopyResultWithHeader
    
    Exit Property
    
err_Let_copyResultWithHeader:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Property
'=========================================================================================
'    function:      readLocalRoot
'    description:   reads the value of local root from the registry
'    arguments:     /
'
'    return value:  /
'
'=========================================================================================
Private Function readLocalRoot() As String
    On Error GoTo errReadLocalRoot
    
    Const FUNCTION_NAME = "readLocalRoot"
    
    '=varibles===================================================================
    Dim bReturn      As Boolean
    Dim lKey         As Long
    Dim sValue       As String
    Dim sKey         As String
    '============================================================================
    
    sValue = Space$(256)
    sKey = m_oComFunc.getRegBasicKey + LOCAL_ROOT + "\" + NOVERSIONDEP
        
    m_oRegFunc.showErrors = False
    bReturn = m_oRegFunc.openKey(HKEY_CURRENT_USER, sKey, KEY_ALL_ACCESS, lKey)
    
    If bReturn = True Then
    
        bReturn = m_oRegFunc.queryValueString(lKey, LOCAL_ROOT, sValue, Len(sValue))
        If bReturn Then
            readLocalRoot = expandEnvironmentVarInPath(Trim(sValue))
        End If
    End If
    
    m_oRegFunc.closeKey sKey, lKey
    
    Exit Function
    
errReadLocalRoot:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Function
'=========================================================================================
'    function:      readLocalRoot
'    description:   reads the value of local root from the registry
'    arguments:     /
'
'    return value:  /
'
'=========================================================================================
Private Function expandEnvironmentVarInPath(ByVal sInput As String) As String
    On Error GoTo errExpandEnvironmentVarInPath
    
    Const FUNCTION_NAME = "expandEnvironmentVarInPath"
    
    Dim pos1 As Long
    Dim pos2 As Long
    Dim sOut     As String
    Dim sTemp   As String
    
    pos1 = InStr(sInput, "%")
    If pos1 > 0 Then
        pos2 = InStr(pos1 + 1, sInput, "%")
        If pos2 > 0 Then
            sOut = left(sInput, pos1 - 1)
            sTemp = Environ(Mid(sInput, pos1 + 1, pos2 - pos1 - 1))
            If Len(sTemp) > 0 Then
                sOut = sOut + sTemp
                sOut = sOut + Right(sInput, Len(sInput) - pos2)
            Else
                sOut = sInput
            End If
        Else
            sOut = sInput
        End If
    Else
        sOut = sInput
    End If

    expandEnvironmentVarInPath = sOut
    
    Exit Function
    
errExpandEnvironmentVarInPath:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Function
Public Property Get localFolderIndependent() As Boolean
    On Error GoTo err_Get_localFolderIndependent
    
    Const FUNCTION_NAME = "P_Get localFolderIndependent"
    
    'see PTS 1117101
    MsgBox LoadResString(300), vbCritical
    
    Exit Property
    
err_Get_localFolderIndependent:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Property
Public Property Let localFolderIndependent(bLocalFolderIndependent As Boolean)
    On Error GoTo err_Let_localFolderIndependent
    
    Const FUNCTION_NAME = "P_LET localFolderIndependent"
    
    'see PTS 1117101
    MsgBox LoadResString(300), vbCritical
    
    Exit Property
    
err_Let_localFolderIndependent:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Property
'=========================================================================================
'    function:      writeStringValue
'    description:   writes the value if failed connects should be removed to the registry
'    arguments:     /
'
'    return value:  /
'
'=========================================================================================
Private Sub writeStringValue(sKeyName As String, sValue As String)
    On Error GoTo errwriteStringValue
    
    Const FUNCTION_NAME = "writeStringValue"
    
    '=varibles===================================================================
    
    Dim bReturn             As Boolean
    Dim lKey                As Long
    Dim lDisPos             As Long
    Dim sKey                As String
    Dim oKey                As SQLStudioUtil.Key
    '=============================================================================
    
        
    sKey = m_oComFunc.getRegBasicKey + PROFILE
    m_oRegFunc.showErrors = False
    bReturn = m_oRegFunc.openKey(HKEY_CURRENT_USER, sKey, KEY_ALL_ACCESS, lKey)
        
    If bReturn = False Then _
       bReturn = m_oRegFunc.createKey(HKEY_CURRENT_USER, sKey, REG_OPTION_NON_VOLATILE, KEY_ALL_ACCESS, lKey, lDisPos)
    
    If bReturn = True Then _
       bReturn = m_oRegFunc.setValueString(lKey, sKeyName, sValue)
    
    m_oRegFunc.closeKey sKey, lKey

    Exit Sub
    
errwriteStringValue:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Sub
'=========================================================================================
'    function:      writeStringValue
'    description:   reads a key value from the registry
'    arguments:     /
'
'    return value:  /
'
'=========================================================================================
Private Function readStringValue(sKeyName As String) As String
    On Error GoTo errReadStringValue
    
    Const FUNCTION_NAME = "readStringValue"
    
    '=varibles===================================================================
    
    Dim sValue              As String
    Dim bReturn             As Boolean
    Dim lKey                As Long
    Dim sKey                As String
    Dim oKey                As SQLStudioUtil.Key
    '=============================================================================
        
    sValue = Space$(1024)
    sKey = m_oComFunc.getRegBasicKey + PROFILE
    
    m_oRegFunc.showErrors = False
    bReturn = m_oRegFunc.openKey(HKEY_CURRENT_USER, sKey, KEY_ALL_ACCESS, lKey)
    
    If bReturn = True Then
        bReturn = m_oRegFunc.queryValueString(lKey, sKeyName, sValue, Len(sValue))
        If bReturn Then
            readStringValue = sValue
        End If
    End If
    
    m_oRegFunc.closeKey sKey, lKey

    Exit Function
    
errReadStringValue:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Function
'=========================================================================================
'    function:      deleteRegEntry
'    description:   delete a sql studio specific registry entry
'    arguments:     /
'
'    return value:  /
'
'=========================================================================================
Private Sub deleteRegEntry(sKeyName As String)
    On Error GoTo errDeleteRegEntry
    
    Const FUNCTION_NAME = "deleteRegEntry"
    
    '=varibles===================================================================
    
    Dim bReturn             As Boolean
    Dim lKey                As Long
    Dim sKey                As String
    Dim oKey                As SQLStudioUtil.Key
    '=============================================================================
    
    sKey = m_oComFunc.getRegBasicKey + sKeyName
    bReturn = m_oRegFunc.openKey(HKEY_CURRENT_USER, sKey, KEY_ALL_ACCESS, lKey)
    If bReturn = True Then _
       bReturn = m_oRegFunc.deleteKey(HKEY_CURRENT_USER, sKey)
       
    m_oRegFunc.closeKey sKey, lKey
  
    Exit Sub
    
errDeleteRegEntry:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Sub


'=========================================================================================
'    function:      writeStringValue
'    description:   reads a key value from the registry
'    arguments:     /
'
'    return value:  /
'
'=========================================================================================
Public Function checkProfileKey() As Boolean
    On Error GoTo errcheckProfileKey
    
    Const FUNCTION_NAME = "checkProfileKey"
    
    '=varibles===================================================================
    
    Dim sValue              As String
    Dim bReturn             As Boolean
    Dim lKey                As Long
    Dim sKey                As String
    Dim oKey                As SQLStudioUtil.Key
    Dim oVal                As SQLStudioUtil.value
    '=============================================================================
        
    sValue = Space$(1024)
    sKey = m_oComFunc.getRegBasicKey + PROFILE
    
    m_oRegFunc.showErrors = False
    checkProfileKey = m_oRegFunc.openKey(HKEY_CURRENT_USER, sKey, KEY_ALL_ACCESS, lKey)
    m_oRegFunc.closeKey sKey, lKey

    Exit Function
    
errcheckProfileKey:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Function
